import { UnknownConstructor, UnknownCreator, UnknownFunction } from '../../types';
import type { Container } from '../Container';
import { Binding, Scope, Type } from './Binding';
export interface EntityBinding extends Binding {
    readonly value: UnknownCreator;
    readonly type: Type.Entity;
    readonly isConstructor: boolean;
}
export interface EntityConstructorBinding extends EntityBinding {
    readonly value: UnknownConstructor;
    readonly isConstructor: true;
}
export interface EntityFunctionBinding extends EntityBinding {
    readonly value: UnknownFunction;
    readonly isConstructor: false;
}
export declare class EntityContainerScopedBinding implements EntityBinding {
    readonly value: UnknownCreator;
    readonly isConstructor: boolean;
    readonly type = Type.Entity;
    readonly scope = Scope.Container;
    readonly cache: WeakMap<Container, unknown>;
    constructor(value: UnknownCreator, isConstructor: boolean);
}
export declare class EntityResolutionScopedBinding implements EntityBinding {
    readonly value: UnknownCreator;
    readonly isConstructor: boolean;
    readonly type = Type.Entity;
    readonly scope = Scope.Resolution;
    constructor(value: UnknownCreator, isConstructor: boolean);
}
export declare class EntitySingletonScopedBinding implements EntityBinding {
    readonly value: UnknownCreator;
    readonly isConstructor: boolean;
    readonly type = Type.Entity;
    readonly scope = Scope.Singleton;
    hasCached: boolean;
    cache?: unknown;
    constructor(value: UnknownCreator, isConstructor: boolean);
    setCache(value: unknown): void;
}
export declare class EntityTransientScopedBinding implements EntityBinding {
    readonly value: UnknownCreator;
    readonly isConstructor: boolean;
    readonly type = Type.Entity;
    readonly scope = Scope.Transient;
    constructor(value: UnknownCreator, isConstructor: boolean);
}
export declare const isEntityBinding: (binding: Binding) => binding is EntityBinding;
export declare const isEntityConstructorBinding: (binding: EntityBinding) => binding is EntityConstructorBinding;
export declare const isEntityContainerScopedBinding: (binding: EntityBinding) => binding is EntityContainerScopedBinding;
export declare const isEntityResolutionScopedBinding: (binding: EntityBinding) => binding is EntityResolutionScopedBinding;
export declare const isEntitySingletonScopedBinding: (binding: EntityBinding) => binding is EntitySingletonScopedBinding;
